# prompt chains
![](https://img.shields.io/badge/version-v0.0.1-blue.svg)
![](https://img.shields.io/badge/python-3.9-blue.svg)
[![Docs](https://img.shields.io/badge/docs-confluence-013A97)]()
![](https://img.shields.io/badge/dev-orange.svg)



Description.

Repo mdl: 
llm-ds-mkt-mdl-ltv-py

Repo dag: 
llm-ds-mkt-lib-reporting-ltv

Dag master branch:
master-pipeliner

Dag: 
mkt_prompt_chains

For any question refer to 
ds-mkt@llm.com.

## Getting Started
Install from [nexus](https://jira.odigeo.com/wiki/display/DS/Python+packages+repositories):


```sh
pip install llm-ds-prompt-chains
```

or from source
```sh
pip install -r requirements.txt
pip install -e .
```

## Authors

*DS team* 

## License

This project is property of *llm*
